# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.1] - 2026-01-20

### Added
- **Realtime WebSocket Client**: Full support for real-time interaction in `magick_mind.realtime`.
- **Resources**:
    - `Chat` and `History` resources for messaging.
    - `Mindspace`, `Project`, `EndUser`, `Corpus` resources for management.
- **Artifacts**: Support for file uploads and attachment handling.
- **Examples**:
    - Detailed `setup_resources.py` script.
    - Complete examples for Realtime Chat and Backend integration.

